=========
Reference
=========

This section displays the help text for each of PyMedPhys' CLI commands. Help
test is sturctured as follows:

.. argparse::
   :ref: pymedphys.cli.define_parser
   :prog: pymedphys
   :nosubcommands:

This presents what to write into the command prompt to use that CLI command.


.. toctree::
    :maxdepth: 1

    dicom
    trf
    pinnacle
    pseudonymisation
